@@ -7,15 +7,25 @@ from torchvision import models, transforms, datasets
 import torchvision.transforms.functional as TF
 import os
 import torch.optim as optim
+import torch.nn.init as init
 from loguru import logger
 
 __all__ = ['Classifier']
 
-MODELS = {'resetnet18': models.resnet18, 'squeezenet1_0': models.squeezenet1_0}
+MODELS = {
+    'resetnet18': models.resnet18,
+    'squeezenet1_0': models.squeezenet1_0,
+    'swin_t': models.swin_t,
+    'swin_s': models.swin_s,
+    'swin_b': models.swin_b
+}
 
 WEIGHTS = {
     'resetnet18': models.ResNet18_Weights.DEFAULT,
-    'squeezenet1_0': models.SqueezeNet1_0_Weights.DEFAULT
+    'squeezenet1_0': models.SqueezeNet1_0_Weights.DEFAULT,
+    'swin_t': models.Swin_T_Weights.DEFAULT,
+    'swin_s': models.Swin_S_Weights.DEFAULT,
+    'swin_b': models.Swin_B_Weights.DEFAULT
 }
 
 
@@ -57,7 +67,7 @@ class Classifier():
         """获取基础模型
 
         Args:
-            model_name (str, optional): 模型名称，目前支持 'resetnet18', 'squeezenet1_0'。 Defaults to 'resetnet18'.
+            model_name (str, optional): 模型名称。可用 `get_avaliable_model_name` 查看支持的模型。 Defaults to 'resetnet18'.
             weights (any, optional): 当为 'pretrained' 时，会载入训练好的参数，
             当为 None 时，会随机初始化参数，当为其它值时，会当作权重文件路径并载入相应的权重。 Defaults to 'pretrained'.
 
@@ -83,7 +93,8 @@ class Classifier():
         """创建分类模型
 
         Args:
-            base_model_name (str): 基础模型名称，创建模型时会以此模型作为骨干网络。目前支持 'resetnet18', 'squeezenet1_0'。
+            base_model_name (str): 基础模型名称，创建模型时会以此模型作为骨干网络。
+            可用 `get_avaliable_model_name` 查看支持的模型。
             num_classes (int): 分类数量
             feature_extract (bool, optional): 为 True 时，进行特征提取，为 False 时，进行微调. Defaults to True.
 
@@ -98,11 +109,23 @@ class Classifier():
             num_ftrs = model_ft.fc.in_features
             model_ft.fc = nn.Linear(num_ftrs, num_classes)
         elif base_model_name == 'squeezenet1_0':
-            model_ft.classifier[1] = nn.Conv2d(512,
-                                               num_classes,
-                                               kernel_size=(1, 1),
-                                               stride=(1, 1))
+            final_conv = nn.Conv2d(512,
+                                   num_classes,
+                                   kernel_size=(1, 1),
+                                   stride=(1, 1))
+            # see https://github.com/pytorch/vision/blob/v0.13.1/torchvision/models/squeezenet.py#L88
+            init.normal_(final_conv.weight, mean=0, std=0.01)
+            if final_conv.bias is not None:
+                init.constant_(final_conv.bias, 0)
+            model_ft.classifier[1] = final_conv
             model_ft.num_classes = num_classes
+        elif base_model_name == 'swin_t' or base_model_name == 'swin_s' or base_model_name == 'swin_b':
+            num_ftrs = model_ft.head.in_features
+            model_ft.head = nn.Linear(num_ftrs, num_classes)
+            # see https://github.com/pytorch/vision/blob/v0.13.1/torchvision/models/swin_transformer.py#L399
+            init.trunc_normal_(model_ft.head.weight, std=0.02)
+            if model_ft.head.bias is not None:
+                init.zeros_(model_ft.head.bias)
         model_ft = model_ft.to(self._device)
         self.model = model_ft
         self.feature_extract = feature_extract
