@@ -53,7 +53,7 @@ class FaceDetector(object):
         except:
             pass
 
-    def detect(self, img):
+    def detect(self, img, overlay=True, threshold=0.5, show_confidence=True):
         """
         检测人脸
 
@@ -70,10 +70,36 @@ class FaceDetector(object):
             [batchId, classId, confidence, left, top, right, bottom]
             see https://github.com/opencv/opencv/blob/f584c6d7239e1d56de0c3bd0232d5ccfaf830084/samples/dnn/object_detection.cpp#L335
         """
-        blob = cv2.dnn.blobFromImage(cv2.resize(img, (300, 300)), 1.0,
-                                     (300, 300), (104.0, 177.0, 123.0))
+        blob = cv2.dnn.blobFromImage(img, 1.0, (300, 300),
+                                     (104.0, 177.0, 123.0))
         self.net.setInput(blob)
-        return self.net.forward()
+        detections = self.net.forward()
+        if not overlay:
+            return detections
+        (h, w) = img.shape[:2]
+        for i in range(detections.shape[2]):
+            # extract the confidence (i.e., probability) associated with the
+            # prediction
+            confidence = detections[0, 0, i, 2]
+
+            # filter out weak detections by ensuring the `confidence` is
+            # greater than the minimum confidence
+            if confidence > threshold:
+                # compute the (x, y)-coordinates of the bounding box for the
+                # object
+                box = detections[0, 0, i, 3:7] * np.array([w, h, w, h])
+                (startX, startY, endX, endY) = box.astype("int")
+
+                # draw the bounding box of the face along with the associated
+                # probability
+                y = startY - 10 if startY - 10 > 10 else startY + 10
+                cv2.rectangle(img, (startX, startY), (endX, endY), (0, 0, 255),
+                              2)
+                if show_confidence:
+                    text = "{:.2f}%".format(confidence * 100)
+                    cv2.putText(img, text, (startX, y),
+                                cv2.FONT_HERSHEY_SIMPLEX, 1, (0, 0, 255), 1)
+        return detections
 
     def draw_boxes(self,
                    img,
@@ -118,4 +144,4 @@ class FaceDetector(object):
                 if show_confidence:
                     text = "{:.2f}%".format(confidence * 100)
                     cv2.putText(img, text, (startX, y),
-                                cv2.FONT_HERSHEY_SIMPLEX, 0.45, (0, 0, 255), 2)
+                                cv2.FONT_HERSHEY_SIMPLEX, 1, (0, 0, 255), 1)
